@@ -11,6 +11,7 @@ const Main = imports.ui.main;
 const Panel = imports.ui.panel;
 const PanelMenu = imports.ui.panelMenu;
 const PopupMenu = imports.ui.popupMenu;
+const PlaceDisplay = imports.ui.placeDisplay;
 
 const ExtensionUtils = imports.misc.extensionUtils;
 const Me = ExtensionUtils.getCurrentExtension();
@@ -27,6 +28,7 @@ const DriveMenuItem = new Lang.Class({
 
 	this.label = new St.Label({ text: place.name });
 	this.addActor(this.label);
+        this.actor.label_actor = this.label;
 
 	let ejectIcon = new St.Icon({ icon_name: 'media-eject',
 				      icon_type: St.IconType.SYMBOLIC,
@@ -52,9 +54,9 @@ const DriveMenu = new Lang.Class({
     Extends: PanelMenu.SystemStatusButton,
 
     _init: function() {
-	this.parent('media-eject');
+	this.parent('media-eject', _("Removable devices"));
 
-	this._manager = Main.placesManager;
+	this._manager = new PlaceDisplay.PlacesManager();
 	this._updatedId = this._manager.connect('mounts-updated', Lang.bind(this, this._update));
 
 	this._contentSection = new PopupMenu.PopupMenuSection();
