@@ -10,6 +10,7 @@ const Main = imports.ui.main;
 const PanelMenu = imports.ui.panelMenu;
 const PopupMenu = imports.ui.popupMenu;
 const Panel = imports.ui.panel;
+const PlaceDisplay = imports.ui.placeDisplay;
 
 const Gettext = imports.gettext.domain('gnome-shell-extensions');
 const _ = Gettext.gettext;
@@ -26,6 +27,7 @@ const PlacesMenu = new Lang.Class({
 
     _init: function() {
         this.parent('folder');
+        this.placesManager = new PlaceDisplay.PlacesManager();
 
         this.defaultItems = [];
         this.bookmarkItems = [];
@@ -38,13 +40,13 @@ const PlacesMenu = new Lang.Class({
         this.menu.addMenuItem(this._devicesMenuItem);
         this._createDevices();
 
-        this._bookmarksId = Main.placesManager.connect('bookmarks-updated',Lang.bind(this,this._redisplayBookmarks));
-        this._mountsId = Main.placesManager.connect('mounts-updated',Lang.bind(this,this._redisplayDevices));
+        this._bookmarksId = this.placesManager.connect('bookmarks-updated',Lang.bind(this,this._redisplayBookmarks));
+        this._mountsId = this.placesManager.connect('mounts-updated',Lang.bind(this,this._redisplayDevices));
     },
 
     destroy: function() {
-        Main.placesManager.disconnect(this._bookmarksId);
-        Main.placesManager.disconnect(this._mountsId);
+        this.placesManager.disconnect(this._bookmarksId);
+        this.placesManager.disconnect(this._mountsId);
 
         this.parent();
     },
@@ -60,12 +62,12 @@ const PlacesMenu = new Lang.Class({
     },
 
     _createDefaultPlaces : function() {
-        this.defaultPlaces = Main.placesManager.getDefaultPlaces();
+        this.defaultPlaces = this.placesManager.getDefaultPlaces();
 
         for (let placeid = 0; placeid < this.defaultPlaces.length; placeid++) {
             this.defaultItems[placeid] = new PopupMenu.PopupMenuItem(this.defaultPlaces[placeid].name);
             let icon = this.defaultPlaces[placeid].iconFactory(PLACE_ICON_SIZE);
-            this.defaultItems[placeid].addActor(icon, { align: St.Align.END });
+            this.defaultItems[placeid].addActor(icon, { align: St.Align.END, span: -1 });
             this.defaultItems[placeid].place = this.defaultPlaces[placeid];
             this.menu.addMenuItem(this.defaultItems[placeid]);
             this.defaultItems[placeid].connect('activate', function(actor,event) {
@@ -76,12 +78,12 @@ const PlacesMenu = new Lang.Class({
     },
 
     _createBookmarks : function() {
-        this.bookmarks = Main.placesManager.getBookmarks();
+        this.bookmarks = this.placesManager.getBookmarks();
 
         for (let bookmarkid = 0; bookmarkid < this.bookmarks.length; bookmarkid++) {
             this.bookmarkItems[bookmarkid] = new PopupMenu.PopupMenuItem(this.bookmarks[bookmarkid].name);
             let icon = this.bookmarks[bookmarkid].iconFactory(PLACE_ICON_SIZE);
-            this.bookmarkItems[bookmarkid].addActor(icon, { align: St.Align.END });
+            this.bookmarkItems[bookmarkid].addActor(icon, { align: St.Align.END, span: -1 });
             this.bookmarkItems[bookmarkid].place = this.bookmarks[bookmarkid];
             this._bookmarksSection.addMenuItem(this.bookmarkItems[bookmarkid]);
             this.bookmarkItems[bookmarkid].connect('activate', function(actor,event) {
@@ -91,12 +93,12 @@ const PlacesMenu = new Lang.Class({
     },
 
     _createDevices : function() {
-        this.devices = Main.placesManager.getMounts();
+        this.devices = this.placesManager.getMounts();
 
         for (let devid = 0; devid < this.devices.length; devid++) {
             this.deviceItems[devid] = new PopupMenu.PopupMenuItem(this.devices[devid].name);
             let icon = this.devices[devid].iconFactory(PLACE_ICON_SIZE);
-            this.deviceItems[devid].addActor(icon, { align: St.Align.END });
+            this.deviceItems[devid].addActor(icon, { align: St.Align.END, span: -1 });
             this.deviceItems[devid].place = this.devices[devid];
             this._devicesMenuItem.menu.addMenuItem(this.deviceItems[devid]);
             this.deviceItems[devid].connect('activate', function(actor,event) {
